import fisica.*;
FWorld world;
PVector pos;

void setup() {
  size(800, 450);
  Fisica.init(this);
  world = new FWorld();
  world.setEdges();
  world.setGravity(0, 0);
  int[] x = {0, 400, 800, 0, 400, 800, 
    200, 125, 150, 100, 175, 
    125, 175, 150, 150, 450};
  int[] y = {0, 0, 0, 450, 450, 450, 
    200, 185, 170, 200, 215, 
    215, 185, 230, 200, 200};
  color[] c = {#000000, #000000, #000000, #000000, #000000, #000000, 
    #FFF400, #005CD3, #CE2721, #BD4CB8, #F06700, 
    #0B8A17, #B70D3A, #333333, #FFD300, #CAFDFF
  };
  for (int i = 0; i < 16; i++) {
    FCircle b = new FCircle(36);
    b.setPosition(x[i], y[i]);
    b.setFillColor(c[i]);
    b.setNoStroke();
    b.setStatic(i < 6);
    b.setName(i < 6 ? "hole" : "ball");
    world.add(b);
  }
}

void draw() {
  background(0, 64, 0);
  world.step();
  world.draw();
  if (pos != null) {
    stroke(255);
    line(pos.x, pos.y, mouseX, mouseY);
  }

  ArrayList<FBody> bodies = world.getBodies();
  for (int i = 0; i < bodies.size(); i++) {
    FBody body = bodies.get(i);
    if (body.getName() == "hole") {
      ArrayList<FContact> contacts = body.getContacts();
      for (int j = 0; j < contacts.size(); j++) {
        FContact c = contacts.get(j);
        if (c.getBody1() == body &&
          c.getBody2().getName() == "ball") {
          world.remove(c.getBody2());
        }
        if (c.getBody2() == body &&
          c.getBody1().getName() == "ball") {
          world.remove(c.getBody1());
        }
      }
    }
  }
}

void mousePressed() {
  pos = new PVector(mouseX, mouseY);
}

void mouseReleased() {
  FBody b = world.getBody(mouseX, mouseY);
  if (b != null) {
    b.addForce((mouseX - pos.x) * 800, (mouseY - pos.y) * 800);
  }
  pos = null;
}
