import fisica.*;
FWorld world;
PImage ball;
float power = 0;
FBox roter, flipLB, flipRB;

void setup() {
  size(600, 800);
  ball = loadImage("ball.png");
  Fisica.init(this);
  world = new FWorld();
  world.setEdges();
  world.remove(world.bottom);
  strokeWeight(10);
  for (int y = 0; y < 7; y++) {
    for (int x = 0; x < 7; x++) {
      float xpos = x*70+15+30*(y%2);
      float ypos = y*70+120;
      if (dist(270, 400, xpos, ypos) < 130) {
        continue;
      }
      createCircle(5, xpos, ypos, true);
    }
  }
  createBox(10, 600, 540, 500, 0, true);
  createBox(180, 5, 90, 650, 0.3, true);
  createBox(180, 5, 440, 650, -0.3, true);
  createBox(200, 10, 510, 70, 0.6, true);
  
  FCircle pivot= createCircle(20, 270, 400, true);
  roter = createBox(200, 20, 270, 400, 0, false);
  FRevoluteJoint joint = new FRevoluteJoint(roter, pivot);
  world.add(joint);
  
  FCircle flipLC = createCircle(10, 190, 700, true);
  FCircle flipRC = createCircle(10, 350, 700, true);
  flipLB = createBox(80, 15, 210, 700, 0, false);
  flipRB = createBox(80, 15, 330, 700, 0, false);
  createJoint(flipLC, flipLB, 190, 700, -0.6, 0.6, 500, 1000);
  createJoint(flipRC, flipRB, 350, 700, -0.6, 0.6, 500, -1000);
}

void draw() {
  background(255);
  if (mousePressed) {
    power = min(power + 1, 190);
  }
  roter.addTorque(50);
  world.step();
  world.draw();
  stroke(0, 255, 255, 80);
  line(0, 790, power*3, 790);
}

void keyPressed() {
  if (keyCode == LEFT) {
    flipLB.addTorque(-30000);
  }
  if (keyCode == RIGHT) {
    flipRB.addTorque(30000);
  }
}

void mouseReleased() {
  FCircle c = createCircle(30, 575, 750, false);
  c.addForce(0, -power*1000);
  c.attachImage(ball);
  power = 0;
}

FCircle createCircle(float size, float x, float y, boolean isStatic) {
  FCircle c = new FCircle(size);
  c.setPosition(x, y);
  c.setStatic(isStatic);
  world.add(c);
  return c;
}
FBox createBox(float w, float h, float x, float y, float r, boolean isStatic) {
  FBox b = new FBox(w, h);
  b.setPosition(x, y);
  b.setRotation(r);
  b.setStatic(isStatic);
  world.add(b);
  return b;
}
FRevoluteJoint createJoint(FBody b0, FBody b1, float x, float y, 
  float lowerAngle, float upperAngle, float torque, float speed) {
  FRevoluteJoint j = new FRevoluteJoint(b0, b1, x, y);
  j.setLowerAngle(lowerAngle);
  j.setUpperAngle(upperAngle);
  j.setEnableLimit(true);
  j.setMaxMotorTorque(torque);
  j.setEnableMotor(true);
  j.setMotorSpeed(speed);
  world.add(j);
  return j;
}
