import fisica.*;
FWorld world;
void setup() {
  size(750, 750, P3D);
  
  Fisica.init(this);
  world = new FWorld();  
  createMaze();
  FCircle ball = new FCircle(40);
  ball.setPosition(50, 50);
  ball.setAllowSleeping(false);
  ball.setFill(0,255,0);
  world.add(ball);
  world.setGravity(0, 0);
  world.setGrabbable(false);  
  noStroke();
}

void draw() {
  background(0);
  
  lights();  
  ArrayList<FBody> bodies = world.getBodies();
  for (int i = 0; i < bodies.size(); i++) {
    FBody body = bodies.get(i);
    if (body instanceof FCircle) {
      drawCircle((FCircle)body);
    }
    if (body instanceof FBox) {
      drawBox((FBox)body);
    }
  }
  
  float xRatio = 1.0 * mouseX / width, yRatio = 1.0 * mouseY / height;
  float xDeg = 90 * xRatio - 45, yDeg = 90 * yRatio - 45;
  world.setGravity(xDeg*15, yDeg*15);
  world.step();

  //world.draw();
}

void createMaze() {
  for (int i = 0; i < 15; i++) {
    createBox(i, 0);
    createBox(i, 14);
    createBox(0, i);
    createBox(14, i);
  }
  for (int y = 2; y < 14; y+=2) {
    for (int x = 2; x < 14; x+=2) {
      createBox(x, y);
      int d = (int)random(y == 2 ? 4 : 3);
      int dx = 0, dy = 0;
      switch(d) {
      case 0:  // left 
        dx = -1; 
        break;
      case 1:  // right
        dx = 1; 
        break;
      case 2:  // down  
        dy = 1;  
        break; 
      case 3:  // up 
        dy = -1; 
        break;
      }
      createBox(x+dx, y+dy);
    }
  }
}

void createBox(int x, int y) {
  FBox box = new FBox(50, 50);   
  box.setPosition(x*50, y*50);
  box.setStatic(true);
  world.add(box);
}

void drawCircle(FCircle circle) {
  pushMatrix();
  translate(circle.getX(), circle.getY());
  fill(0, 255, 0);
  sphere(circle.getSize()/2);
  popMatrix();
}

void drawBox(FBox b) {
  pushMatrix();
  translate(b.getX(), b.getY());
  fill(255);
  box(b.getWidth(), b.getHeight(), 100);
  popMatrix();
}
